@@ -10,10 +10,15 @@ import mss
 
 # -- General configuration ------------------------------------------------
 
-extensions = ["sphinx.ext.intersphinx"]
+extensions = [
+    "sphinx_copybutton",
+    "sphinx.ext.intersphinx",
+    "sphinx_new_tab_link",
+]
 templates_path = ["_templates"]
 source_suffix = {".rst": "restructuredtext"}
 master_doc = "index"
+new_tab_link_show_external_link_icon = True
 
 # General information about the project.
 project = "Python MSS"
@@ -28,7 +33,20 @@ todo_include_todos = True
 
 # -- Options for HTML output ----------------------------------------------
 
-html_theme = "default"
+html_theme = "shibuya"
+html_theme_options = {
+    "accent_color": "lime",
+    "globaltoc_expand_depth": 1,
+    "toctree_titles_only": False,
+}
+html_favicon = "../icon.png"
+html_context = {
+    "source_type": "github",
+    "source_user": "BoboTiG",
+    "source_repo": "python-mss",
+    "source_docs_path": "/docs/source/",
+    "source_version": "main",
+}
 htmlhelp_basename = "PythonMSSdoc"
 
 
