@@ -1,24 +1,20 @@
-"""
-This is part of the MSS Python's module.
-Source: https://github.com/BoboTiG/python-mss
+"""This is part of the MSS Python's module.
+Source: https://github.com/BoboTiG/python-mss.
 
 Simple naive benchmark to compare with:
     https://pythonprogramming.net/game-frames-open-cv-python-plays-gta-v/
 """
+
 import time
 
 import cv2
-import numpy
+import numpy as np
+from PIL import ImageGrab
 
 import mss
 
 
 def screen_record() -> int:
-    try:
-        from PIL import ImageGrab
-    except ImportError:
-        return 0
-
     # 800x600 windowed mode
     mon = (0, 40, 800, 640)
 
@@ -27,7 +23,7 @@ def screen_record() -> int:
     last_time = time.time()
 
     while time.time() - last_time < 1:
-        img = numpy.asarray(ImageGrab.grab(bbox=mon))
+        img = np.asarray(ImageGrab.grab(bbox=mon))
         fps += 1
 
         cv2.imshow(title, cv2.cvtColor(img, cv2.COLOR_BGR2RGB))
@@ -48,7 +44,7 @@ def screen_record_efficient() -> int:
     last_time = time.time()
 
     while time.time() - last_time < 1:
-        img = numpy.asarray(sct.grab(mon))
+        img = np.asarray(sct.grab(mon))
         fps += 1
 
         cv2.imshow(title, img)
