@@ -1,10 +1,10 @@
-"""
-This is part of the MSS Python's module.
-Source: https://github.com/BoboTiG/python-mss
+"""This is part of the MSS Python's module.
+Source: https://github.com/BoboTiG/python-mss.
 
 Example using the multiprocessing module to speed-up screen capture.
     https://github.com/pythonlessons/TensorFlow-object-detection-tutorial
 """
+
 from multiprocessing import Process, Queue
 
 import mss
@@ -40,6 +40,6 @@ if __name__ == "__main__":
     # The screenshots queue
     queue: Queue = Queue()
 
-    # 2 processes: one for grabing and one for saving PNG files
+    # 2 processes: one for grabbing and one for saving PNG files
     Process(target=grab, args=(queue,)).start()
     Process(target=save, args=(queue,)).start()
