@@ -1,9 +1,9 @@
-"""
-This is part of the MSS Python's module.
-Source: https://github.com/BoboTiG/python-mss
+"""This is part of the MSS Python's module.
+Source: https://github.com/BoboTiG/python-mss.
 
 Usage example with a specific display.
 """
+
 import mss
 
 with mss.mss(display=":0.0") as sct:
