@@ -1,9 +1,9 @@
-"""
-This is part of the MSS Python's module.
-Source: https://github.com/BoboTiG/python-mss
+"""This is part of the MSS Python's module.
+Source: https://github.com/BoboTiG/python-mss.
 
 Example to capture part of the screen.
 """
+
 import mss
 import mss.tools
 
