@@ -1,9 +1,9 @@
-"""
-This is part of the MSS Python's module.
-Source: https://github.com/BoboTiG/python-mss
+"""This is part of the MSS Python's module.
+Source: https://github.com/BoboTiG/python-mss.
 
 PIL example using frombytes().
 """
+
 from PIL import Image
 
 import mss
