@@ -2,7 +2,6 @@
 Source: https://github.com/BoboTiG/python-mss.
 """
 
-import platform
 from collections.abc import Generator
 from hashlib import sha256
 from pathlib import Path
@@ -10,8 +9,6 @@ from zipfile import ZipFile
 
 import pytest
 
-from mss import mss
-
 
 @pytest.fixture(autouse=True)
 def _no_warnings(recwarn: pytest.WarningsRecorder) -> Generator:
@@ -48,17 +45,3 @@ def raw() -> bytes:
 
     assert sha256(data).hexdigest() == "d86ed4366d5a882cfe1345de82c87b81aef9f9bf085f4c42acb6f63f3967eccd"
     return data
-
-
-@pytest.fixture(scope="session")
-def pixel_ratio() -> int:
-    """Get the pixel, used to adapt test checks."""
-    if platform.system().lower() != "darwin":
-        return 1
-
-    # Grab a 1x1 screenshot
-    region = {"top": 0, "left": 0, "width": 1, "height": 1}
-
-    with mss() as sct:
-        # On macOS with Retina display, the width can be 2 instead of 1
-        return sct.grab(region).size[0]
